@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"os/exec"
 	"path/filepath"
 	"runtime"
 	"strings"
@@ -38,9 +39,12 @@ func printUsage(output io.Writer, flagSet *flag.FlagSet, printCommandline bool)
 	_, _ = fmt.Fprintln(output, "  moar [options] <file>")
 	_, _ = fmt.Fprintln(output, "  ... | moar")
 	_, _ = fmt.Fprintln(output, "  moar < file")
-	_, _ = fmt.Fprintln(output, "")
+	_, _ = fmt.Fprintln(output)
 	_, _ = fmt.Fprintln(output, "Shows file contents. Compressed files will be transparently decompressed.")
 	_, _ = fmt.Fprintln(output)
+	_, _ = fmt.Fprintln(output, "More information + source code:")
+	_, _ = fmt.Fprintln(output, "  <https://github.com/walles/moar#readme>")
+	_, _ = fmt.Fprintln(output)
 	_, _ = fmt.Fprintln(output, "Environment:")
 	if len(moarEnv) == 0 {
 		_, _ = fmt.Fprintln(output, "  Additional options are read from the MOAR environment variable if set.")
@@ -49,28 +53,68 @@ func printUsage(output io.Writer, flagSet *flag.FlagSet, printCommandline bool)
 		_, _ = fmt.Fprintln(output, "  Additional options are read from the MOAR environment variable.")
 		_, _ = fmt.Fprintf(output, "  Current setting: MOAR=\"%s\"\n", moarEnv)
 	}
-	_, _ = fmt.Fprintln(output)
-	_, _ = fmt.Fprintln(output, "Options:")
 
-	flagSet.PrintDefaults()
-
-	moarPath, err := filepath.Abs(os.Args[0])
+	absMoarPath, err := absLookPath(os.Args[0])
 	if err == nil {
-		pagerValue, err := filepath.Abs(os.Getenv("PAGER"))
+		absPagerValue, err := absLookPath(os.Getenv("PAGER"))
 		if err != nil {
-			pagerValue = ""
+			absPagerValue = ""
 		}
-		if pagerValue != moarPath {
+		if absPagerValue != absMoarPath {
 			// We're not the default pager
 			_, _ = fmt.Fprintln(output)
-			_, _ = fmt.Fprintln(output, "To make Moar your default pager, put the following line in")
-			_, _ = fmt.Fprintln(output, "your .bashrc or .bash_profile and it will be default in all")
-			_, _ = fmt.Fprintln(output, "new terminal windows:")
-			_, _ = fmt.Fprintf(output, "   export PAGER=%s\n", moarPath)
+			_, _ = fmt.Fprintln(output, "Making moar your default pager:")
+			_, _ = fmt.Fprintln(output, "  Put the following line in your ~/.bashrc, ~/.bash_profile or ~/.zshrc")
+			_, _ = fmt.Fprintln(output, "  and moar will be used as the default pager in all new terminal windows:")
+			_, _ = fmt.Fprintln(output)
+			_, _ = fmt.Fprintf(output, "     export PAGER=%s\n", getMoarPath())
 		}
 	} else {
 		log.Warn("Unable to find moar binary ", err)
 	}
+
+	_, _ = fmt.Fprintln(output)
+	_, _ = fmt.Fprintln(output, "Options:")
+
+	flagSet.PrintDefaults()
+}
+
+// "moar" if we're in the $PATH, otherwise an absolute path
+func getMoarPath() string {
+	moarPath := os.Args[0]
+	if filepath.IsAbs(moarPath) {
+		return moarPath
+	}
+
+	if strings.Contains(moarPath, string(os.PathSeparator)) {
+		// Relative path
+		moarPath, err := filepath.Abs(moarPath)
+		if err != nil {
+			panic(err)
+		}
+		return moarPath
+	}
+
+	// Neither absolute nor relative, try PATH
+	_, err := exec.LookPath(moarPath)
+	if err != nil {
+		panic("Unable to find in $PATH: " + moarPath)
+	}
+	return moarPath
+}
+
+func absLookPath(path string) (string, error) {
+	lookedPath, err := exec.LookPath(path)
+	if err != nil {
+		return "", err
+	}
+
+	absLookedPath, err := filepath.Abs(lookedPath)
+	if err != nil {
+		return "", err
+	}
+
+	return absLookedPath, err
 }
 
 // printProblemsHeader prints bug reporting information to stderr
@@ -106,6 +150,14 @@ func parseStyleOption(styleOption string, flagSet *flag.FlagSet) chroma.Style {
 }
 
 func parseColorsOption(colorsOption string, flagSet *flag.FlagSet) chroma.Formatter {
+	if strings.ToLower(colorsOption) == "auto" {
+		colorsOption = "16M"
+		if strings.Contains(os.Getenv("TERM"), "256") {
+			// Covers "xterm-256color" as used by the macOS Terminal
+			colorsOption = "256"
+		}
+	}
+
 	switch strings.ToUpper(colorsOption) {
 	case "8":
 		return formatters.TTY8
@@ -125,6 +177,45 @@ func parseColorsOption(colorsOption string, flagSet *flag.FlagSet) chroma.Format
 	panic("We just did os.Exit(), why are we still executing?")
 }
 
+func parseStatusBarStyle(styleOption string, flagSet *flag.FlagSet) m.StatusBarStyle {
+	if styleOption == "inverse" {
+		return m.STATUSBAR_STYLE_INVERSE
+	}
+	if styleOption == "plain" {
+		return m.STATUSBAR_STYLE_PLAIN
+	}
+	if styleOption == "bold" {
+		return m.STATUSBAR_STYLE_BOLD
+	}
+
+	fmt.Fprintf(os.Stderr,
+		"ERROR: Unrecognized status bar style \"%s\", good ones are inverse, plain and bold.\n",
+		styleOption)
+	fmt.Fprintln(os.Stderr)
+	printUsage(os.Stderr, flagSet, true)
+
+	os.Exit(1)
+	panic("os.Exit(1) just failed")
+}
+
+func parseUnprintableStyle(styleOption string, flagSet *flag.FlagSet) m.UnprintableStyle {
+	if styleOption == "highlight" {
+		return m.UNPRINTABLE_STYLE_HIGHLIGHT
+	}
+	if styleOption == "whitespace" {
+		return m.UNPRINTABLE_STYLE_WHITESPACE
+	}
+
+	fmt.Fprintf(os.Stderr,
+		"ERROR: Unrecognized invalid UTF8 rendering style \"%s\", good ones are highlight or whitespace.\n",
+		styleOption)
+	fmt.Fprintln(os.Stderr)
+	printUsage(os.Stderr, flagSet, true)
+
+	os.Exit(1)
+	panic("os.Exit(1) just failed")
+}
+
 func main() {
 	// FIXME: If we get a CTRL-C, get terminal back into a useful state before terminating
 
@@ -148,9 +239,12 @@ func main() {
 	wrap := flagSet.Bool("wrap", false, "Wrap long lines")
 	styleOption := flagSet.String("style", "native",
 		"Highlighting style from https://xyproto.github.io/splash/docs/longer/all.html")
-	colorsOption := flagSet.String("colors", "16M", "Highlighting palette size: 8, 16, 256, 16M")
+	colorsOption := flagSet.String("colors", "auto", "Highlighting palette size: 8, 16, 256, 16M, auto")
 	noLineNumbers := flagSet.Bool("no-linenumbers", false, "Hide line numbers on startup, press left arrow key to show")
+	noStatusBar := flagSet.Bool("no-statusbar", false, "Hide the status bar, toggle with '='")
 	noClearOnExit := flagSet.Bool("no-clear-on-exit", false, "Retain screen contents when exiting moar")
+	statusBarStyleOption := flagSet.String("statusbar", "inverse", "Status bar style: inverse, plain or bold")
+	UnprintableStyleOption := flagSet.String("render-unprintable", "highlight", "How unprintable characters are rendered: highlight or whitespace")
 
 	// Combine flags from environment and from command line
 	flags := os.Args[1:]
@@ -178,6 +272,8 @@ func main() {
 
 	style := parseStyleOption(*styleOption, flagSet)
 	formatter := parseColorsOption(*colorsOption, flagSet)
+	statusBarStyle := parseStatusBarStyle(*statusBarStyleOption, flagSet)
+	unprintableStyle := parseUnprintableStyle(*UnprintableStyleOption, flagSet)
 
 	log.SetLevel(log.InfoLevel)
 	if *trace {
@@ -208,7 +304,7 @@ func main() {
 
 	if inputFilename == nil && !stdinIsRedirected {
 		fmt.Fprintln(os.Stderr, "ERROR: Filename or input pipe required")
-		fmt.Fprintln(os.Stderr, "")
+		fmt.Fprintln(os.Stderr)
 		printUsage(os.Stderr, flagSet, true)
 		os.Exit(1)
 	}
@@ -247,7 +343,7 @@ func main() {
 	if stdinIsRedirected {
 		// Display input pipe contents
 		reader := m.NewReaderFromStream("", os.Stdin)
-		startPaging(reader, *wrap, *noLineNumbers, *noClearOnExit)
+		startPaging(reader, *wrap, *noLineNumbers, *noStatusBar, *noClearOnExit, statusBarStyle, unprintableStyle)
 		return
 	}
 
@@ -257,10 +353,14 @@ func main() {
 		fmt.Fprintf(os.Stderr, "ERROR: %v\n", err)
 		os.Exit(1)
 	}
-	startPaging(reader, *wrap, *noLineNumbers, *noClearOnExit)
+	startPaging(reader, *wrap, *noLineNumbers, *noStatusBar, *noClearOnExit, statusBarStyle, unprintableStyle)
 }
 
-func startPaging(reader *m.Reader, wrapLongLines bool, noLineNumbers bool, noClearOnExit bool) {
+func startPaging(reader *m.Reader,
+	wrapLongLines, noLineNumbers, noStatusBar, noClearOnExit bool,
+	statusBarStyle m.StatusBarStyle,
+	unprintableStyle m.UnprintableStyle,
+) {
 	screen, e := twin.NewScreen()
 	if e != nil {
 		panic(e)
@@ -271,6 +371,9 @@ func startPaging(reader *m.Reader, wrapLongLines bool, noLineNumbers bool, noCle
 	pager := m.NewPager(reader)
 	pager.WrapLongLines = wrapLongLines
 	pager.ShowLineNumbers = !noLineNumbers
+	pager.ShowStatusBar = !noStatusBar
+	pager.StatusBarStyle = statusBarStyle
+	pager.UnprintableStyle = unprintableStyle
 
 	defer func() {
 		// Restore screen...
