@@ -34,7 +34,7 @@ type Screen interface {
 	// NOTE: Never cache this response! On window resizes you'll get an
 	// EventResize on the Screen.Events channel, and this method will start
 	// returning the new size instead.
-	Size() (int, int)
+	Size() (width int, height int)
 
 	// ShowCursorAt() moves the cursor to the given screen position and makes
 	// sure it is visible.
@@ -58,11 +58,11 @@ type UnixScreen struct {
 	events chan Event
 
 	ttyIn            *os.File
-	oldTerminalState *term.State //lint:ignore U1000 Not used on Windows
-	oldTtyInMode     uint32      //lint:ignore U1000 Windows only
+	oldTerminalState *term.State //nolint Not used on Windows
+	oldTtyInMode     uint32      //nolint Windows only
 
 	ttyOut        *os.File
-	oldTtyOutMode uint32 //lint:ignore U1000 Windows only
+	oldTtyOutMode uint32 //nolint Windows only
 }
 
 // Example event: "\x1b[<65;127;41M"
@@ -302,7 +302,7 @@ func consumeEncodedEvent(encodedEventSequences string) (*Event, string) {
 // NOTE: Never cache this response! On window resizes you'll get an EventResize
 // on the Screen.Events channel, and this method will start returning the new
 // size instead.
-func (screen *UnixScreen) Size() (int, int) {
+func (screen *UnixScreen) Size() (width int, height int) {
 	select {
 	case <-screen.sigwinch:
 		// Resize logic needed, see below
